import 'reflect-metadata';
import { ObjectSchema } from 'joi';
export declare const controllerMetaKey: unique symbol;
export declare const methodsMetaKey: unique symbol;
export declare function Controller(path: string): (target: any) => any;
export declare function Tags(...args: string[]): (target: any) => any;
export declare function ControllerMethod(method: Method, path?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Get(path?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Post(path?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Put(path?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Delete(path?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Parameters(schemas: ValidationSchemas): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Response<T>(code: number, _description: string, examples?: T[]): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
export declare function Description(description: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => any;
interface ValidationSchemas {
    pathParametersSchema?: ObjectSchema;
    queryStringParametersSchema?: ObjectSchema;
    headersSchema?: ObjectSchema;
    bodySchema?: ObjectSchema;
}
export declare type Method = 'GET' | 'POST' | 'PUT' | 'DELETE';
export interface MethodMapping {
    propertyKey: string;
    method?: Method;
    path?: string;
    parameters?: ValidationSchemas;
    responseExamples?: Record<string, any[]>;
    description?: string;
}
export interface ControllerProperties {
    basePath?: string;
    tags?: string[];
}
export {};
