"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HandlerFactory = void 0;
const autobind_decorator_1 = require("autobind-decorator");
const Errors_1 = require("../Errors");
let databaseSecret = undefined;
class HandlerFactory {
    constructor(router, logger, secretsManager, requestContextRegistry, oracleDb, oracleDbConfig) {
        this.router = router;
        this.logger = logger;
        this.secretsManager = secretsManager;
        this.requestContextRegistry = requestContextRegistry;
        this.oracleDb = oracleDb;
        this.oracleDbConfig = oracleDbConfig;
    }
    getHandler() {
        return async (request, context) => {
            this.requestContextRegistry.clearContext();
            context.callbackWaitsForEmptyEventLoop = false;
            if (this.oracleDbConfig.createPool) {
                const { oracleDbSecretName } = this.oracleDbConfig;
                if (!oracleDbSecretName)
                    throw new Errors_1.InternalServerError('No oracleDb secret name specified');
                if (!databaseSecret)
                    databaseSecret = await this.secretsManager.getSecret(oracleDbSecretName);
                try {
                    this.oracleDb.getPool();
                }
                catch (e) {
                    if (e.message.includes('NJS-047')) {
                        const { password, user } = databaseSecret;
                        const { poolIncrement, poolMax, poolMin, connectString } = this.oracleDbConfig;
                        await this.oracleDb.createPool({
                            connectString,
                            user,
                            password,
                            poolIncrement: poolIncrement ?? 1,
                            poolMax: poolMax ?? 3,
                            poolMin: poolMin ?? 0,
                        });
                    }
                    else {
                        this.logger.error(e.message);
                    }
                }
            }
            const executionContext = extractExecutionContext(request);
            this.requestContextRegistry.setContext(executionContext);
            const { response } = await this.router.route(request, context);
            return response;
        };
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], HandlerFactory.prototype, "getHandler", null);
exports.HandlerFactory = HandlerFactory;
function extractExecutionContext(request) {
    const identity = getIdentity(request);
    return {
        authMethod: 'apikey',
        identityData: identity,
        identitySummary: identity,
        requestId: request.requestContext.requestId,
        path: request.path,
        method: request.httpMethod,
        sourceIp: request.requestContext?.identity?.sourceIp,
    };
}
function getIdentity(request) {
    const apiKey = request.requestContext?.identity?.apiKey;
    if (apiKey) {
        const startOfApiKey = apiKey.substring(0, 5);
        return `apikey ${startOfApiKey}*****`;
    }
    return 'unknown';
}
