import oracledb from 'oracledb';
import { Cache } from '../Cache';
export declare abstract class AbstractRepository {
    private oracleDb;
    private cache;
    constructor(oracleDb: typeof oracledb, cache: Cache);
    abstract readonly repositoryDomain: string;
    /**
     * Returns an oracledb connection. Don't forget to close it when your're done :)
     */
    getConnection(): Promise<oracledb.Connection>;
    /**
     * Wrapper for oracledb.connection.execute that handles connection opening / closing
     * and query result caching. It Gets a connection, executes a query, commits,
     * closes the connection and return results. The first three arguments are passed
     * to oracledb.connection.execute as provided, while the fourth argument controls
     * request caching ttl. The default ttl is 0, which means no caching is used.
     * Returns oracledb.Result.rows
     */
    execute<T>(query: string, bindParams: oracledb.BindParameters, options: oracledb.ExecuteOptions, cachingOptions?: CachingOptions): Promise<T[]>;
}
export interface CachingOptions {
    ttlInSecs?: number;
    cacheTags?: string[];
    responseTimeoutInMillis?: number;
    throwOnTimeout?: boolean;
    cacheEmptyQueryResult?: boolean;
}
