import { APIGatewayProxyEvent, Context } from 'aws-lambda';
import { LambdaRouter, RouterParams } from 'lambda-router';
import { Router, Event, Route, RouterContext } from './Router';
import { Logger } from '../Logger';
export declare abstract class AbstractRouter implements Router {
    private logger;
    constructor(logger: Logger, routes?: Route[], routerParams?: RouterParams);
    protected readonly router: LambdaRouter;
    protected readonly tracingEnabled: boolean;
    protected readonly allowedRequestProperties: string[];
    protected readonly headersToRemove: string[];
    addRoutes(routes: Route[]): this;
    route(event: APIGatewayProxyEvent, context: Context): Promise<{
        isOk: boolean;
        endpoint: string;
        uri: string;
        response: {
            statusCode: number;
            body: string;
            headers: Record<string, string>;
        };
    }>;
    protected preprocessRequest(event: Event, _context: Context, _path: string, _method: string): void;
    protected logRequest(event: Event, _context: Context, _path: string, _method: string): void;
    /** Response on resource / method not found */
    protected abstract onUnknown(event: Event, context: RouterContext, path: string, method: string): unknown;
    /** Mutates the event/context and perform global scope validations */
    protected abstract beforeRoute(event: Event, context: Context, path: string, method: string): void;
}
