"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractRouter = void 0;
const lambda_router_1 = require("lambda-router");
const lodash_1 = require("lodash");
const autobind_decorator_1 = require("autobind-decorator");
class AbstractRouter {
    constructor(logger, routes, routerParams) {
        this.logger = logger;
        this.allowedRequestProperties = [
            'headers',
            'queryStringParameters',
            'multiValueQueryStringParameters',
            'pathParameters',
            'rawBody',
            'isBase64Encoded',
        ];
        this.headersToRemove = ['authorization', 'x-api-key'];
        this.router = lambda_router_1.Router({
            extractPathParameters: routerParams?.extractPathParameters ?? true,
            includeErrorStack: routerParams?.includeErrorStack ?? false,
            cors: routerParams?.cors ?? false,
            parseBody: routerParams?.parseBody ?? true,
            decodeEvent: routerParams?.decodeEvent ?? true,
            normalizeHeaders: routerParams?.normalizeHeaders ?? true,
        });
        this.tracingEnabled = routerParams?.tracingEnabled ?? true;
        this.router.unknown(this.onUnknown);
        this.router.beforeRoute(this.preprocessRequest);
        this.router.beforeRoute(this.logRequest);
        this.router.beforeRoute(this.beforeRoute);
        this.router.formatError((_statusCode, error) => error.data || error);
        if (routes)
            this.addRoutes(routes);
    }
    addRoutes(routes) {
        for (const route of routes) {
            const { path } = route;
            if (route.get)
                this.router.get(path, route.get);
            if (route.post)
                this.router.post(path, route.post);
            if (route.put)
                this.router.put(path, route.put);
            if (route.delete)
                this.router.delete(path, route.delete);
        }
        return this;
    }
    async route(event, context) {
        const response = await this.router.route(event, context);
        if (this.tracingEnabled)
            this.logger.info(response);
        return response;
    }
    preprocessRequest(event, _context, _path, _method) {
        for (const prop in this.allowedRequestProperties) {
            delete event[prop];
        }
        if (typeof lodash_1.get(event, 'pathParameters.path') === 'string') {
            delete event.pathParameters?.path;
        }
        for (const header of Object.keys(event.headers)) {
            if (this.headersToRemove.includes(header.toLowerCase())) {
                delete event.headers[header];
            }
        }
    }
    logRequest(event, _context, _path, _method) {
        if (this.tracingEnabled)
            this.logger.info(event);
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], AbstractRouter.prototype, "addRoutes", null);
__decorate([
    autobind_decorator_1.boundMethod
], AbstractRouter.prototype, "route", null);
__decorate([
    autobind_decorator_1.boundMethod
], AbstractRouter.prototype, "preprocessRequest", null);
__decorate([
    autobind_decorator_1.boundMethod
], AbstractRouter.prototype, "logRequest", null);
exports.AbstractRouter = AbstractRouter;
