import { APIGatewayProxyEvent, Context } from 'aws-lambda';
export interface Router {
    addRoutes: (routes: Route[]) => void;
    route: (request: APIGatewayProxyEvent, context: Context) => Promise<ApiGatewayProxyResponse>;
}
export interface Route {
    path: string;
    get?: RouteHandler;
    post?: RouteHandler;
    put?: RouteHandler;
    delete?: RouteHandler;
}
export interface ApiGatewayProxyResponse {
    isOk: boolean;
    endpoint: string;
    uri: string;
    response: {
        statusCode: number;
        body: string;
        headers: Record<string, string>;
    };
}
export declare type RouteHandler = (event: Event, context: RouterContext) => Promise<HttpResponse>;
export interface Event {
    headers: Record<string, string>;
    multiValueHeaders: Record<string, string[]>;
    queryStringParameters: Record<string, string> | null;
    multiValueQueryStringParameters: Record<string, string[]> | null;
    pathParameters: Record<string, string> | null;
    rawBody: string | null;
    isBase64Encoded: boolean;
}
export interface HttpResponse {
    statusCode: number;
    body: any;
    headers?: Record<string, string>;
}
export interface RouterContext extends Context {
    response: RouterResponseBuilder;
}
declare type RouterResponseBuilder = (statusCode: number, body: any, headers?: Record<string, string>) => Promise<any>;
export {};
